# Py_Pass
This is a random password generator in python that does NOT store ANY of your data.

**Where can I use it ?:**

- Windows (.exe compiled version available on [GitHub](https://github.com/ZKAW/Py-Pass))
- Ubuntu
- macOS

**With this script, you can:**

- Select the password length
- Enable/disable numbers
- Enable/disable special chars
- Change the special char list

**HOW TO USE:**

- `from py_pass import randPass`
- `print(randPass())`

randPass can take four arguments:

- stringLength -> Password length, in integer.
- isNumber -> Is the password should include numbers, in boolean.
- isSpecial -> Is the password should include special characters, in boolean.
- specialChars -> The special characters ASCII map, in string.

**HOW TO HELP ME:**

- Like and fork my github
- Tell your friend about it ! :)

**INFO**

GitHub link: https://github.com/ZKAW/PyPass

**! DISCLAIMER !**

This script is not storing ANY of your data, so you can use it in a totally transparent and safe way. Enjoy ! :)
